## :space_invader: About

This code generates random text based on a string of Lorem Ipsum. It uses the `random` module to randomly select words from the string to build sentences and paragraphs. The `generate_word` function selects a single word from the string; `generate_sentence` builds a sentence by randomly selecting a number of words and adding a period at the end of the sentence. It may also insert commas based on the length of the sentence. `generate_paragraph` creates a paragraph by randomly selecting a number of sentences; `generate_text` creates a block of text by randomly selecting a number of paragraphs. The printed statements in the code test each of these functions to ensure that they work properly.

## :runner:  Usage

The code can be run in the terminal using the following command:

python lorem_generator.py

## :raising_hand: Contribution

All contributions are welcome! Please open an issue or submit a pull request.
